@@ -1,20 +1,12 @@
-from typing import Optional, TypeVar
+from typing import Optional
 
 from pydantic import BaseModel, Field
 
-from mongorepository.models.base import ObjectIdStr
-
-T = TypeVar("T", bound=BaseModel)
+from mongorepository.models.base import ObjectIdField
 
 
 class MongoBaseModel(BaseModel):
-    id: Optional[ObjectIdStr] = Field(alias="_id")
-
-    def update_from_model(self, model: T) -> None:
-        updates = model.dict(exclude_none=True)
-        fields = updates.keys()
-        for field in fields:
-            setattr(self, field, updates[field])
+    id: Optional[ObjectIdField] = Field(alias="_id")
 
     @classmethod
     def projection(cls) -> dict:
